@@ -26,15 +26,13 @@
 
 #ifndef ASSERTION_INCLUDED
 #define ASSERTION_INCLUDED
-#include "AssertException.h"
-
 
 /**
  * The assert() macro tests the given expression and if it is false, raise
  * an AssertException. Unless a previous installed exception handler catch
  * the exception, it will cause the application to abort. If expression is 
- * true, the assert() macro does nothing. <small>The assert() macro is 
- * required and may <b>not</b> be removed at compile time.</small>
+ * true, the assert() macro does nothing. The assert macro can be removed
+ * at compile time by defining NDEBUG which is the case for optimised build
  * @see AssertException.h 
  *
  * @author http://www.tildeslash.com/
@@ -43,19 +41,12 @@
  */
 
 #undef assert
-/** @cond hide */
+#ifdef NDEBUG
+#define assert(e) ((void)0)
+#else
+#include "AssertException.h"
 extern void assert(int e);
-/** @endcond */
-
-
-/**
- * Evaluate the given expression <code>e</code> and if false raise
- * an AssertException
- * @param e The expression to evaluate
- * @exception AssertException if <code>e</code> is false
- * @hideinitializer
- */
 #define assert(e) ((void)((e)||(Exception_throw(&(AssertException), __func__, __FILE__, __LINE__, #e),0)))
-
+#endif
 
 #endif
